/*
   An attempt to perform postprocess hatching. The 'hatching' sampler
   consists of opposite strokes in the red and blue channel. Depending
   on the average colorvalue of the render-to-texture, the end color
   is determined, using 3 intervals:
   0.0 - 0.3
   0.3 - 0.7
   0.7 - 1.0
*/
float blend;
float brightness;
float4 ambiance;
sampler RT: register(s0);
sampler hatching: register(s1);
float4 main_ps(float2 UV0 : TEXCOORD0, float2 UV1 : TEXCOORD1) : COLOR
{
	float4 scnColor = tex2D(RT, UV0);
	float4 strokes = tex2D(hatching, UV1);
	float4 p1 = strokes.r;
	float4 p2 = strokes.g;
	float4 p3 = strokes.b;
	float4 endCol;
	float average = (scnColor.r + scnColor.g + scnColor.b) / 3.0;
	if (average < 0.3)
		endCol = average * p1;
	else
	if (average < 0.7)
		endCol = average * p3;
	else
		endCol = p2;

	// Apply blending
	scnColor *= (1-blend);
	endCol *= ambiance;
	endCol *= blend;
	return saturate (scnColor + brightness * endCol);
}
